import React, { useState, useEffect, useCallback } from 'react';
import PageHeader from '@/components/PageHeader';
import Map from '@/components/map';
import TopNavigator from '@/components/topNavigator';
import RunNavRight from './components/topNavRight';
import { FormattedMessage, history } from 'umi';
import styles from './index.less';
import mapstyles from '@/assets/css/map.less';
import Icon from '@/tenants-ui/Icon';
import SearchInput from '@/components/SearchInput';
import moment from 'moment';

import { queryDeviceTimeManage } from '@/services/ant-design-pro/environment';

type runtimeNavType = {
  normalRun: any;
  overtimeWork: number;
  overtimeBook: number;
};

const Runtime: React.FC = () => {
  // const { maptemp6 } = equipImageMap;

  const [searchText, setSearchText] = useState<string>();
  const [runtimeNav, setRuntimeNav] = useState<runtimeNavType>({});
  //const [mapList, setMapList] = useState<API.MapInfo[]>([]);
  const [selFloorId, setSelFloorId] = useState<string>();
  const [selTime, setSelTime] = useState<string>(moment().format('YYYYMMDD'));
  const changeFloorId = (data: string) => {
    debugger;
    setSelFloorId(data);
  };
  const checkRecord = () => {
    history.push('/runtime/recordList');
    console.log('showR');
  };
  const changeTime = (time) => {
    debugger;
    var timeStr = time.format('YYYYDMMDD');
    setSelTime(timeStr);
  };
  useEffect(() => {
    if (selFloorId && selTime) {
      debugger;
      queryDeviceTimeManage({
        //floorId: selFloorId,
        floorId: 'Fl11010802593241ec348ecb4148806b9034c8957454',
        date: selTime,
        //date: 20220212,
      }).then(function (res) {
        debugger;
        var resdata = res || {};
        setRuntimeNav({
          normalRun: resdata.workTimeNum,
          overtimeWork: resdata.overTimeNum,
          overtimeBook: resdata.meetTimeNum,
        });
        var resList = res.content || [];
        resList.forEach((item) => {
          item.runTimeStatus = 'normalRun';
          if (item.hasOwnProperty('meetTime')) {
            debugger;
            item.runTimeStatus = 'overtimeBook';
          }
          if (item.hasOwnProperty('overTimeStartTime')) {
            debugger;
            item.runTimeStatus = 'overtimeWork';
          }
        });
      });
    }
  }, [selFloorId, selTime]);
  return (
    <>
      <PageHeader
        title={<FormattedMessage id="menu.runtime" />}
        action={
          //   <div className={styles.headerRight}>
          //     <div className={styles.check} onClick={checkRecord} style={{ display: 'none' }}>
          //       <Icon className="" style={{ marginRight: 6 }} type="document" />
          //       <span>查看加班记录</span>
          //     </div>
          //   </div>
          <SearchInput
            onSearch={(s) => {
              setSearchText(s);
            }}
          />
        }
      />
      <TopNavigator
        type={'runtime'}
        action={<RunNavRight runtimeNav={runtimeNav} changeTime={changeTime}></RunNavRight>}
        changeFloorId={changeFloorId}
      ></TopNavigator>
      <div className={styles.maptop}>
        <div className={styles.right}></div>
      </div>
      {/* <div className={styles.map}>
            <div className={styles.specialRoom}></div>
            <img src={mapImg}></img>
          </div> */}
      {/* <div
              className={mapstyles.house}
              style={{
                width: 180,
                height: 100,
              }}
            >
              <div className={mapstyles.allTime}>08:00-23:00</div>
              <div className={mapstyles.content}>
                <Icon className="" type="office" style={{ fontSize: 20 }}></Icon>
                <div className={mapstyles.name}>Jozy Zone</div>
              </div>
            </div> */}
      <Map
        searchText={searchText}
        selFloorId={selFloorId}
        type={'runtime'}
        render={(item, index) => {
          return (
            <div
              key={index + 'house'}
              className={mapstyles.house}
              style={{
                left: item.left,
                top: item.top,
                width: item.width,
                height: item.height,
                backgroundColor:
                  item.runTimeStatus == 'normalRun'
                    ? 'rgba(196, 196, 196, 0.2)'
                    : item.runTimeStatus == 'overtimeWork'
                    ? 'rgba(94, 139, 207, 0.2)'
                    : 'rgba(0, 220, 35, 0.2)',
              }}
            >
              <div className={mapstyles.allTime}>
                {(item.timeList || []).map(function (titem: string, tindex: number) {
                  return <span key={tindex + 'time'}>{titem},</span>;
                })}
              </div>
              <div className={mapstyles.content}>
                <Icon className="" type={item.roomFuncType} style={{ fontSize: 20 }}></Icon>
                <div className={mapstyles.name}>{item.localName}</div>
              </div>
            </div>
          );
        }}
      ></Map>
    </>
  );
};
export default Runtime;
